#[non_exhaustive]pub enum GatewaySearchErrorKind {
Transport,
Backend,
}Expand description
Which side of a Gateway web search failed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Transport
Sending the request or reading a successful reply failed, timeouts included.
Backend
The Gateway answered with a failure status or an unusable body.